==> bootstrap_1.0-6.tar.gz: bootstrap/data/law82.R <==
"law82" <-
structure(list(V1 = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 
61, 62, 62, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 
77, 78, 79, 80, 81, 82), V2 = c(622, 542, 579, 653, 606, 576, 
620, 615, 553, 607, 558, 596, 635, 581, 661, 547, 599, 646, 622, 
611, 546, 614, 628, 575, 662, 627, 608, 632, 587, 581, 605, 704, 
477, 591, 578, 572, 615, 606, 603, 535, 595, 575, 573, 644, 545, 
645, 651, 562, 609, 555, 586, 580, 594, 594, 560, 641, 512, 631, 
597, 621, 617, 637, 572, 610, 562, 635, 614, 546, 598, 666, 570, 
570, 605, 565, 686, 608, 595, 590, 558, 611, 564, 575), V3 = c(3.23, 
2.83, 3.24, 3.12, 3.09, 3.39, 3.1, 3.4, 2.97, 2.91, 3.11, 3.24, 
3.3, 3.22, 3.43, 2.91, 3.23, 3.47, 3.15, 3.33, 2.99, 3.19, 3.03, 
3.01, 3.39, 3.41, 3.04, 3.29, 3.16, 3.17, 3.13, 3.36, 2.57, 3.02, 
3.03, 2.88, 3.37, 3.2, 3.23, 2.98, 3.11, 2.92, 2.85, 3.38, 2.76, 
3.27, 3.36, 3.19, 3.17, 3, 3.11, 3.07, 2.96, 3.05, 2.93, 3.28, 
3.01, 3.21, 3.32, 3.24, 3.03, 3.33, 3.08, 3.13, 3.01, 3.3, 3.15, 
2.82, 3.2, 3.44, 3.01, 2.92, 3.45, 3.15, 3.5, 3.16, 3.19, 3.15, 
2.81, 3.16, 3.02, 2.74)), class = "data.frame", row.names = c("1", 
"2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
"14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
"25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", 
"36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", 
"47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", 
"58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", 
"69", "70", "71", "72", "73", "74", "75", "76", "77", "78", "79", 
"80", "81", "82"))

==> bootstrap_1.0-18.tar.gz: bootstrap/data/law82.R <==
"law82" <-
structure(list(School = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 
61, 62, 62, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 
77, 78, 79, 80, 81, 82), LSAT = c(622, 542, 579, 653, 606, 576, 
620, 615, 553, 607, 558, 596, 635, 581, 661, 547, 599, 646, 622, 
611, 546, 614, 628, 575, 662, 627, 608, 632, 587, 581, 605, 704, 
477, 591, 578, 572, 615, 606, 603, 535, 595, 575, 573, 644, 545, 
645, 651, 562, 609, 555, 586, 580, 594, 594, 560, 641, 512, 631, 
597, 621, 617, 637, 572, 610, 562, 635, 614, 546, 598, 666, 570, 
570, 605, 565, 686, 608, 595, 590, 558, 611, 564, 575), GPA = c(3.23, 
2.83, 3.24, 3.12, 3.09, 3.39, 3.1, 3.4, 2.97, 2.91, 3.11, 3.24, 
3.3, 3.22, 3.43, 2.91, 3.23, 3.47, 3.15, 3.33, 2.99, 3.19, 3.03, 
3.01, 3.39, 3.41, 3.04, 3.29, 3.16, 3.17, 3.13, 3.36, 2.57, 3.02, 
3.03, 2.88, 3.37, 3.2, 3.23, 2.98, 3.11, 2.92, 2.85, 3.38, 2.76, 
3.27, 3.36, 3.19, 3.17, 3, 3.11, 3.07, 2.96, 3.05, 2.93, 3.28, 
3.01, 3.21, 3.32, 3.24, 3.03, 3.33, 3.08, 3.13, 3.01, 3.3, 3.15, 
2.82, 3.2, 3.44, 3.01, 2.92, 3.45, 3.15, 3.5, 3.16, 3.19, 3.15, 
2.81, 3.16, 3.02, 2.74)), class = "data.frame", row.names = c("1", 
"2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
"14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
"25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", 
"36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", 
"47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", 
"58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", 
"69", "70", "71", "72", "73", "74", "75", "76", "77", "78", "79", 
"80", "81", "82"))
